@@ -157,12 +157,12 @@ def run_migrations(host: str, bypass_super: str, bypass_jaaql: str, db_interface
                     config_name = ".".join(fname.split(".")[0:-1])
                     configs.append([config_name, join(config_loc, fname)])
 
-                encoded_configs = [[USERNAME__jaaql, host, USERNAME__jaaql, MARKER__bypass + bypass_super, DB__jaaql],
-                                   [USERNAME__superuser, host, USERNAME__super_db, MARKER__jaaql_bypass + bypass_jaaql, DB__postgres]]
+                encoded_configs = [[USERNAME__jaaql, host, USERNAME__jaaql, MARKER__jaaql_bypass + bypass_jaaql, DB__jaaql],
+                                   [USERNAME__superuser, host, USERNAME__super_db, MARKER__bypass + bypass_super, DB__postgres]]
 
                 start_time = datetime.now()
 
-                initialise(actual_file_name, content, configs, encoded_configs)
+                initialise(actual_file_name, content, configs, encoded_configs, host)
 
                 execution_time = time_delta_ms(start_time, datetime.now())
                 version = script_file.split("__")[0][1:]
